@@ -57,11 +57,13 @@
 #include <time.h>
 #include <unistd.h>
 
-#ifdef BSD
+#if defined(BSD) && !defined(__GNU__)
 #include <sys/param.h>
 #include <sys/user.h>
 #include <sys/sysctl.h>
 #include <kvm.h>
+#else
+#include <sys/param.h>
 #endif
 
 #include "rc.h"
@@ -87,6 +89,7 @@ librc_hidden_proto(rc_find_pids)
 librc_hidden_proto(rc_getfile)
 librc_hidden_proto(rc_getline)
 librc_hidden_proto(rc_newer_than)
+librc_hidden_proto(rc_proc_getent)
 librc_hidden_proto(rc_older_than)
 librc_hidden_proto(rc_runlevel_exists)
 librc_hidden_proto(rc_runlevel_get)
