@@ -46,6 +46,7 @@
 
 #include "builtins.h"
 #include "einfo.h"
+#include "queue.h"
 #include "rc.h"
 #include "rc-misc.h"
 
@@ -173,7 +174,7 @@ rc_depend(int argc, char **argv)
 			break;
 
 		case_RC_COMMON_GETOPT
-			    }
+		}
 	}
 
 	if (deptree_file) {
